Index: recipes/dartium.py |
diff --git a/recipes/mojo.py b/recipes/dartium.py |
similarity index 72% |
copy from recipes/mojo.py |
copy to recipes/dartium.py |
index f7316ace9299b1066e1b315ba165fdf6fd372280..d026533e8774f8bfed300dc1195aa0f6ee3a760c 100644 |
--- a/recipes/mojo.py |
+++ b/recipes/dartium.py |
@@ -1,4 +1,4 @@ |
-# Copyright 2014 The Chromium Authors. All rights reserved. |
+# Copyright 2015 The Chromium Authors. All rights reserved. |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
@@ -9,16 +9,16 @@ import recipe_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Mojo(recipe_util.Recipe): |
- """Basic Recipe class for Mojo.""" |
+class Dart(recipe_util.Recipe): |
+ """Basic Recipe class for Dart.""" |
@staticmethod |
def fetch_spec(props): |
- url = 'https://github.com/domokit/mojo.git' |
+ url = 'https://github.com/dart-lang/sdk.git' |
solution = { |
- 'name' :'src', |
+ 'name' :'src/dart', |
'url' : url, |
- 'deps_file': 'DEPS', |
+ 'deps_file': 'tools/deps/dartium.deps/DEPS', |
'managed' : False, |
'custom_deps': {}, |
'safesync_url': '', |
@@ -39,7 +39,7 @@ class Mojo(recipe_util.Recipe): |
def main(argv=None): |
- return Mojo().handle_args(argv) |
+ return Dart().handle_args(argv) |
if __name__ == '__main__': |